institution

# XMLRésuméLibrary: User Guide

instantMessage | Element Reference | interest

## Name

institution — A name of an academic institution

## Synopsis

### Content Model

    (#PCDATA|emphasis|citation|url|link)*

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `institution` element specifies the name of a degree-awarding institution, such as a university, college, or trade school.

### Parents

`institution` may be contained in these elements: `degree`

### Attributes

`id`

  A string used to uniquely identify an institution. The institution may then be referred to by this identifier.

## See Also

`organization`.

## Examples

    <degree>
      <level>BA</level>
      <major>Daisy Chain Manufacturing</major>
      <institution>Harvard</institution>
    </degree>

instantMessage | Element Reference | interest